@@ -17,7 +17,7 @@ class connector:
 		grant_type ='client_credentials'
 		scope = "public projects profile elearning tig forum"
 		try:
-			reply = requests.post(url,auth=(UID, SECRET),data={'scopes': scope, 'grant_type':grant_type,'client_id':UID,'client_secret':SECRET})
+			reply = requests.post(url,auth=(UID, SECRET),data={'scope': scope, 'grant_type':grant_type,'client_id':UID,'client_secret':SECRET})
 			reply.raise_for_status()
 		except requests.exceptions.HTTPError as err:
 				exit(print(self.RED + err))
@@ -161,7 +161,7 @@ class connector:
 				print(self.GREEN + "Success POST on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
-			print(self.RED + err + 'on DELETE ' + url + self.DEFAULT)
+			print(self.RED + str(err) + 'on DELETE ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
 	def build_list_email(self, all_logins):
